From 1ff416cc61a8c17a8edbc5742474e99a356e803c Mon Sep 17 00:00:00 2001
From: Rohit D Borkar <rohitborkar00@gmail.com>
Date: Tue, 6 Apr 2021 10:24:50 +0000
Subject: [PATCH] CDDA appears twice in side pane (Issue #486)

Fixes #486
MR !91
---
 thunar/thunar-device-monitor.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/thunar/thunar-device-monitor.c b/thunar/thunar-device-monitor.c
index 0e8272767..c79ce8c45 100644
--- a/thunar/thunar-device-monitor.c
+++ b/thunar/thunar-device-monitor.c
@@ -510,9 +510,10 @@ thunar_device_monitor_mount_added (GVolumeMonitor      *volume_monitor,
       if (G_UNLIKELY (location == NULL))
         return;
 
       /* skip gphoto and mtp locations, since those also have a volume */
       if (g_file_has_uri_scheme (location, "gphoto2")
-          || g_file_has_uri_scheme (location, "mtp"))
+          || g_file_has_uri_scheme (location, "mtp")
+          || g_file_has_uri_scheme (location, "cdda"))
         {
           g_object_unref (location);
           return;
@@ -510,9 +510,10 @@ thunar_device_monitor_mount_added (GVolumeMonitor      *volume_monitor,
         return;
 
-      /* skip gphoto and mtp locations, since those also have a volume */
+      /* skip gphoto, mtp and cdda locations, since those also have a volume */
       if (g_file_has_uri_scheme (location, "gphoto2")
-- 
GitLab